@@ -19,8 +19,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef __MG_PROPERTY_MODEL_H__
-#define __MG_PROPERTY_MODEL_H__
+#ifndef __PLANNER_PROPERTY_MODEL_H__
+#define __PLANNER_PROPERTY_MODEL_H__
 
 #include <gtk/gtktreemodel.h>
 #include <libplanner/mrp-project.h>
@@ -30,13 +30,20 @@ enum {
 	COL_LABEL,
 	COL_TYPE,
 	COL_VALUE,
-	COL_PROPERTY,
+	COL_PROPERTY
 };
 
-GtkTreeModel *planner_property_model_new (MrpProject *project,
-				     GType       owner_type);
+typedef struct {
+	GType		 owner_type;
+	GtkListStore 	*store;
+} MrpPropertyStore;
 
-#endif /* __MG_PROPERTY_MODEL_H__ */
+GtkTreeModel *planner_property_model_new (MrpProject       *project,
+					  GType             owner_type,
+					  MrpPropertyStore *shop);
+
+
+#endif /* __PLANNER_PROPERTY_MODEL_H__ */
 
 
 
